Svg icons are preferred as they are plain text files that play nicely with git.
Please make sure to update the sources table when adding or updating images.

# Sources for resources

| File | Source | Notes | Author |
|---|---|---|---|
| ![](hab_gui/resources/habihat-white.svg) [habihat-white.svg](hab_gui/resources/habihat-white.svg) |  |  | Blur Studio |
| ![](hab_gui/resources/habihat.svg) [habihat.svg](hab_gui/resources/habihat.svg) |  |  | Blur Studio |
| ![](hab_gui/resources/menu.svg) [menu.svg](hab_gui/resources/menu.svg) | https://pictogrammers.com/library/mdi/icon/menu/ |  | Google |
| ![](hab_gui/resources/pin-off-outline.svg) [pin-off-outline.svg](hab_gui/resources/pin-off-outline.svg) | https://pictogrammers.com/library/mdi/icon/pin-off-outline/ |  | Google |
| ![](hab_gui/resources/pin-outline.svg) [pin-outline.svg](hab_gui/resources/pin-outline.svg) | https://pictogrammers.com/library/mdi/icon/pin-outline/ |  | Google |
| ![](hab_gui/resources/refresh.svg) [refresh.svg](hab_gui/resources/refresh.svg) | https://pictogrammers.com/library/mdi/icon/refresh/ |  | Google |
